=====================================
GraphQL implementation for Python 3.6
=====================================

GraphQL ia a query language created by Facebook. This package
supports `the latest <http://facebook.github.io/graphql/October2016/>`_
on the moment of writing specification of the language.

Current status is alpha.